package com.example.e10favouritecities

import android.os.Bundle
import androidx.activity.ComponentActivity
import androidx.activity.compose.setContent
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.material3.MaterialTheme
import androidx.compose.material3.Surface
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.ui.Modifier
import androidx.compose.ui.tooling.preview.Preview
import com.example.e10favouritecities.ui.theme.E10FavouriteCitiesTheme
import com.google.android.gms.maps.model.CameraPosition
import com.google.android.gms.maps.model.LatLng
import com.google.maps.android.compose.GoogleMap
import com.google.maps.android.compose.Marker
import com.google.maps.android.compose.MarkerState
import com.google.maps.android.compose.rememberCameraPositionState

class MainActivity : ComponentActivity() {
    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContent {
            E10FavouriteCitiesTheme {
                // A surface container using the 'background' color from the theme
                Surface(
                    modifier = Modifier.fillMaxSize(),
                    color = MaterialTheme.colorScheme.background
                ) {
                    App()
                }
            }
        }
    }
}



@Composable
fun App() {
    val markerPositions = listOf(
        MarkerData(LatLng(62.241046, 25.750684), "Jyvaskyla", "Marker in Jyvaskyla"),
        MarkerData(LatLng(60.167464, 24.938049), "Helsinki", "Marker in Helsinki"),
        MarkerData(LatLng(60.426297, 22.277340), "Turku", "Marker in Turku"),
        MarkerData(LatLng(61.486884, 23.779909), "Tampere", "Marker in Tampere"),
        MarkerData(LatLng(63.076507, 21.752947), "Vaasa", "Marker in Vaasa"),
        MarkerData(LatLng(64.985984, 25.527193), "Oulu", "Marker in Oulu"),
        MarkerData(LatLng(62.890296, 27.655160), "Kuopio", "Marker in Kuopio"),
    )
    val cameraPositionState = rememberCameraPositionState {
        position = CameraPosition.fromLatLngZoom(markerPositions[0].position, 5.5f)
    }
    GoogleMap(
        modifier = Modifier.fillMaxSize(),
        cameraPositionState = cameraPositionState
    ){
        for (marker in markerPositions){
            Marker(
                state = MarkerState(position = marker.position),
                title = marker.title,
                snippet = marker.snippet
            )
        }
    }
}

data class MarkerData(
    val position: LatLng,
    val title: String,
    val snippet: String
)